changeset 2230:fd017ca43d8d

Merge
author asaha
date Mon, 19 Mar 2018 13:40:00 -0700
parents 2a90c09417a3 (current diff) aa85fe4a8d69 (diff)
children b8243acd4c11 98ffd83833d5
files .hgtags common/autoconf/generated-configure.sh
diffstat 3 files changed, 16 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/.hgtags	Mon Mar 19 12:12:27 2018 -0700
+++ b/.hgtags	Mon Mar 19 13:40:00 2018 -0700
@@ -821,6 +821,11 @@
 3b37f1a6ba6b98a8aa9b0b43e96b374a22a21b99 jdk8u162-b11
 173b2b978c05e59aa471e82be9013955ebd6b4de jdk8u162-b12
 a127ef57877d806f0840ccd6e7a2be337692fe6e jdk8u162-b31
+2c309abde14fbef07fe07304f493f770da0f5564 jdk8u162-b32
+f8f11c61855441c2d2ec1f87ba76e379fb371cd5 jdk8u162-b33
+a916a62cdb9cbdd7fd6ef5fa2e69092454f4fbab jdk8u162-b34
+6b0ed08eb07843e581354b94c2b48bf0bac59161 jdk8u162-b35
+539957b71bf6f416e16f9509c385eeca0a4e796b jdk8u162-b36
 d66f57333c7fcc735f87eb0903ffdc0aaf899b32 jdk8u171-b00
 6e7e84f6107b55b5cb98f5ac5e3bffa3e4b8892f jdk8u171-b01
 28f638905f78913e5b6dc89dd88e37223984a105 jdk8u171-b02
--- a/common/autoconf/toolchain.m4	Mon Mar 19 12:12:27 2018 -0700
+++ b/common/autoconf/toolchain.m4	Mon Mar 19 13:40:00 2018 -0700
@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2011, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
 # DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 #
 # This code is free software; you can redistribute it and/or modify it
@@ -1211,9 +1211,10 @@
         LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker --hash-style=both "
       fi
       if test "x$OPENJDK_TARGET_OS" = xlinux; then
-        # And since we now know that the linker is gnu, then add -z defs, to forbid
-        # undefined symbols in object files.
-        LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker -z -Xlinker defs"
+        # And since we now know that the linker is gnu, then add:
+        #   -z defs, to forbid undefined symbols in object files
+        #   -z noexecstack, to mark stack regions as non-executable
+        LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker -z -Xlinker defs -Xlinker -z -Xlinker noexecstack"
         if test "x$DEBUG_LEVEL" = "xrelease"; then
           # When building release libraries, tell the linker optimize them.
           # Should this be supplied to the OSS linker as well?
--- a/common/autoconf/generated-configure.sh	Mon Mar 19 12:12:27 2018 -0700
+++ b/common/autoconf/generated-configure.sh	Mon Mar 19 13:40:00 2018 -0700
@@ -3776,7 +3776,7 @@
 
 
 #
-# Copyright (c) 2011, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
 # DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 #
 # This code is free software; you can redistribute it and/or modify it
@@ -3912,7 +3912,7 @@
 #CUSTOM_AUTOCONF_INCLUDE
 
 # Do not change or remove the following line, it is needed for consistency checks:
-DATE_WHEN_GENERATED=1521483882
+DATE_WHEN_GENERATED=1521491924
 
 ###############################################################################
 #
@@ -30178,9 +30178,10 @@
         LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker --hash-style=both "
       fi
       if test "x$OPENJDK_TARGET_OS" = xlinux; then
-        # And since we now know that the linker is gnu, then add -z defs, to forbid
-        # undefined symbols in object files.
-        LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker -z -Xlinker defs"
+        # And since we now know that the linker is gnu, then add:
+        #   -z defs, to forbid undefined symbols in object files
+        #   -z noexecstack, to mark stack regions as non-executable
+        LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker -z -Xlinker defs -Xlinker -z -Xlinker noexecstack"
         if test "x$DEBUG_LEVEL" = "xrelease"; then
           # When building release libraries, tell the linker optimize them.
           # Should this be supplied to the OSS linker as well?